==> maven-dependency-analyzer_1.11.1.orig.tar.xz: maven-dependency-analyzer-maven-dependency-analyzer-1.11.1/src/test/java/org/apache/maven/shared/dependency/analyzer/ProjectDependencyAnalyzerExceptionTest.java <==
package org.apache.maven.shared.dependency.analyzer;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import junit.framework.TestCase;

/**
 * Tests <code>ProjectDependencyAnalyzerException</code>.
 * 
 * @author <a href="mailto:markhobson@gmail.com">Mark Hobson</a>
 * @version $Id$
 * @see ProjectDependencyAnalyzerException
 */
public class ProjectDependencyAnalyzerExceptionTest extends TestCase
{
    // tests ------------------------------------------------------------------

    public void testConstructor()
    {
        ProjectDependencyAnalyzerException exception = new ProjectDependencyAnalyzerException( "a" );

        assertEquals( "a", exception.getMessage() );
    }

    public void testConstructorWithThrowable()
    {
        Throwable throwable = new Exception();
        ProjectDependencyAnalyzerException exception = new ProjectDependencyAnalyzerException( "a", throwable );

        assertEquals( "a", exception.getMessage() );
        assertEquals( throwable, exception.getCause() );
    }
}

==> maven-dependency-analyzer_1.13.0.orig.tar.xz: maven-dependency-analyzer-maven-dependency-analyzer-1.13.0/src/test/java/org/apache/maven/shared/dependency/analyzer/ProjectDependencyAnalyzerExceptionTest.java <==
package org.apache.maven.shared.dependency.analyzer;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.junit.Test;

import static org.assertj.core.api.Assertions.assertThat;

/**
 * Tests <code>ProjectDependencyAnalyzerException</code>.
 * 
 * @author <a href="mailto:markhobson@gmail.com">Mark Hobson</a>
 * @see ProjectDependencyAnalyzerException
 */
public class ProjectDependencyAnalyzerExceptionTest
{
    @Test
    public void testConstructor()
    {
        assertThat( new ProjectDependencyAnalyzerException( "a" ) ).hasMessage( "a" );
    }

    @Test
    public void testConstructorWithThrowable()
    {
        Throwable throwable = new Exception();
        ProjectDependencyAnalyzerException exception = new ProjectDependencyAnalyzerException( "a", throwable );

        assertThat( exception ).hasMessage( "a" ).hasCause( throwable );
    }
}
